pub struct Offer {
pub id: OfferId,
pub template_id: OfferTemplateId,
pub created_at: DateTime<Utc>,
}Fields
id: OfferIdtemplate_id: OfferTemplateIdcreated_at: DateTime<Utc>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Offer
impl<'de> Deserialize<'de> for Offer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Offer
impl JsonSchema for Offer
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for Offer
impl Ord for Offer
Sourceimpl PartialOrd for Offer
impl PartialOrd for Offer
Sourceimpl Tsify for Offer
impl Tsify for Offer
const DECL: &'static str = "export interface Offer {\n id: OfferId;\n template_id: OfferTemplateId;\n created_at: DateTime<Utc>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Offer
impl StructuralPartialEq for Offer