pub struct OfferTemplate {Show 17 fields
pub id: OfferTemplateId,
pub alias: String,
pub title: I18nString,
pub icon_path: String,
pub reward_bundle_id: BundleId,
pub payment_type: PaymentType,
pub limit_of_buys: Option<i64>,
pub buys_reset_seconds: Option<u64>,
pub limit_buy_text: Option<I18nString>,
pub events_subscribe: Vec<String>,
pub trigger_script: String,
pub shop_tab: ShopTab,
pub enabled: bool,
pub flag_new: bool,
pub flag_sale: Option<u32>,
pub value: Option<u32>,
pub priority: u32,
}Fields
id: OfferTemplateIdalias: Stringtitle: I18nStringicon_path: Stringreward_bundle_id: BundleIdpayment_type: PaymentTypelimit_of_buys: Option<i64>buys_reset_seconds: Option<u64>limit_buy_text: Option<I18nString>events_subscribe: Vec<String>trigger_script: Stringshop_tab: ShopTabenabled: boolflag_new: boolflag_sale: Option<u32>value: Option<u32>priority: u32Trait Implementations
Sourceimpl Clone for OfferTemplate
impl Clone for OfferTemplate
Sourcefn clone(&self) -> OfferTemplate
fn clone(&self) -> OfferTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OfferTemplate
impl Debug for OfferTemplate
Sourceimpl<'de> Deserialize<'de> for OfferTemplate
impl<'de> Deserialize<'de> for OfferTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OfferTemplate
impl JsonSchema for OfferTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OfferTemplate
impl PartialEq for OfferTemplate
Sourceimpl Serialize for OfferTemplate
impl Serialize for OfferTemplate
Sourceimpl Tsify for OfferTemplate
impl Tsify for OfferTemplate
const DECL: &'static str = "export interface OfferTemplate {\n id: OfferTemplateId;\n alias: string;\n title: I18nString;\n icon_path: string;\n reward_bundle_id: BundleId;\n payment_type: PaymentType;\n limit_of_buys: number | null;\n buys_reset_seconds: number | null;\n limit_buy_text: I18nString | null;\n events_subscribe: string[];\n trigger_script: string;\n shop_tab: ShopTab;\n enabled: boolean;\n flag_new: boolean;\n flag_sale: number | null;\n value: number | null;\n priority: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for OfferTemplate