pub struct OffersInfo {
pub active_offers: Vec<Offer>,
pub offer_buy_counts: BTreeMap<OfferTemplateId, u32>,
}Fields
active_offers: Vec<Offer>offer_buy_counts: BTreeMap<OfferTemplateId, u32>Trait Implementations
Sourceimpl Clone for OffersInfo
impl Clone for OffersInfo
Sourcefn clone(&self) -> OffersInfo
fn clone(&self) -> OffersInfo
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OffersInfo
impl Debug for OffersInfo
Sourceimpl Default for OffersInfo
impl Default for OffersInfo
Sourcefn default() -> OffersInfo
fn default() -> OffersInfo
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OffersInfo
impl<'de> Deserialize<'de> for OffersInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OffersInfo
impl JsonSchema for OffersInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OffersInfo
impl PartialEq for OffersInfo
Sourceimpl Serialize for OffersInfo
impl Serialize for OffersInfo
Sourceimpl Tsify for OffersInfo
impl Tsify for OffersInfo
const DECL: &'static str = "export interface OffersInfo {\n active_offers: Offer[];\n offer_buy_counts: Record<OfferTemplateId, number>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for OffersInfo
impl StructuralPartialEq for OffersInfo