pub struct ShopTabConfig {
pub tab: ShopTab,
pub name: I18nString,
}Fields
tab: ShopTabname: I18nStringTrait Implementations
Sourceimpl Clone for ShopTabConfig
impl Clone for ShopTabConfig
Sourcefn clone(&self) -> ShopTabConfig
fn clone(&self) -> ShopTabConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShopTabConfig
impl Debug for ShopTabConfig
Sourceimpl<'de> Deserialize<'de> for ShopTabConfig
impl<'de> Deserialize<'de> for ShopTabConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShopTabConfig
impl JsonSchema for ShopTabConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ShopTabConfig
impl PartialEq for ShopTabConfig
Sourceimpl Serialize for ShopTabConfig
impl Serialize for ShopTabConfig
Sourceimpl Tsify for ShopTabConfig
impl Tsify for ShopTabConfig
const DECL: &'static str = "export interface ShopTabConfig {\n tab: ShopTab;\n name: I18nString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for ShopTabConfig